Coverage for C:\src\imod-python\imod\mf6\interfaces\imodel.py: 69%

1 from typing import Optional, Tuple

2

3 from imod.mf6.interfaces.idict import IDict

4 from imod.mf6.statusinfo import StatusInfoBase

5 from imod.typing import GridDataArray

6

7

8 class IModel(IDict):

9 """

10 Interface for imod.mf6.model.Modflow6Model

11 """

12

13 def mask_all_packages(self, mask: GridDataArray):

14 raise NotImplementedError

15

16 def purge_empty_packages(self, model_name: Optional[str] = "") -> None:

17 raise NotImplementedError

18

19 def validate(self, model_name: str = "") -> StatusInfoBase:

20 raise NotImplementedError

21

22 @property

23 def domain(self):

24 raise NotImplementedError

25

26 def is_regridding_supported(self) -> Tuple[bool, str]:

27 raise NotImplementedError